/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.fs.http.client;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.CommonConfigurationKeysPublic;
import org.apache.hadoop.fs.Path;
import org.apache.hadoop.test.TestHdfsHelper;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;

@RunWith(value = Parameterized.class)
public class TestHttpFSWithHttpFSFileSystem extends BaseTestHttpFSWith {

  public TestHttpFSWithHttpFSFileSystem(Operation operation) {
    super(operation);
  }

  @Override
  protected Class getFileSystemClass() {
    return HttpFSFileSystem.class;
  }

  @Override
  protected Path getProxiedFSTestDir() {
    return TestHdfsHelper.getHdfsTestDir();
  }

  @Override
  protected String getProxiedFSURI() {
    return TestHdfsHelper.getHdfsConf().get(
      CommonConfigurationKeysPublic.FS_DEFAULT_NAME_KEY);
  }

  @Override
  protected Configuration getProxiedFSConf() {
    return TestHdfsHelper.getHdfsConf();
  }

}
