/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.yarn.exceptions;

import org.apache.hadoop.classification.InterfaceAudience.Public;
import org.apache.hadoop.classification.InterfaceStability.Unstable;
import org.apache.hadoop.yarn.api.ApplicationClientProtocol;
import org.apache.hadoop.yarn.api.protocolrecords.GetApplicationReportRequest;

/**
 * This exception is thrown on
 * {@link ApplicationClientProtocol#getApplicationReport
 * (GetApplicationReportRequest)} API
 * when the Application doesn't exist in RM and AHS
 */
@Public
@Unstable
public class ApplicationNotFoundException extends YarnException{

  private static final long serialVersionUID = 8694408L;

  public ApplicationNotFoundException(Throwable cause) {
    super(cause);
  }

  public ApplicationNotFoundException(String message) {
    super(message);
  }

  public ApplicationNotFoundException(String message,
      Throwable cause) {
    super(message, cause);
  }
}
